@@ -40,6 +40,7 @@ from opentelemetry.trace import (
     StatusCode,
 )
 from opentelemetry import trace
+from opentelemetry.util.http import remove_url_credentials
 from cisco_opentelemetry_specifications import SemanticAttributes
 
 from ..utils import Utils
@@ -109,22 +110,20 @@ def create_trace_config(
 
         http_method = params.method.upper()
         request_span_name = f"HTTP {http_method}"
+        request_url = remove_url_credentials(str(params.url))
+
+        span_attributes = {
+            SpanAttributes.HTTP_METHOD: http_method,
+            SpanAttributes.HTTP_URL: request_url,
+        }
 
         trace_config_ctx.span = trace_config_ctx.tracer.start_span(
-            request_span_name,
-            kind=SpanKind.CLIENT,
+            request_span_name, kind=SpanKind.CLIENT, attributes=span_attributes
         )
 
         if callable(request_hook):
             request_hook(trace_config_ctx.span, params)
 
-        if trace_config_ctx.span.is_recording():
-            attributes = {
-                SpanAttributes.HTTP_METHOD: http_method,
-            }
-            for key, value in attributes.items():
-                trace_config_ctx.span.set_attribute(key, value)
-
         trace_config_ctx.token = context_api.attach(
             trace.set_span_in_context(trace_config_ctx.span)
         )
